from setuptools import find_packages, setup

setup(
    name='psifi',
    version='0.0.1',
    packages=find_packages(where='.'),
    maintainer='Agnostiq',
    author='Agnostiq',
    install_requires=[],
    url='https://github.com/wjcunningham7/psifi',
    download_url='https://github.com/wjcunningham7/psifi/archive/v0.0.1.tar.gz',
)
